# Generated by Django 2.2.8 on 2022-05-24 15:15

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('departments', '0009_auto_20220524_1512'),
    ]

    operations = [
        # migrations.AlterModelTable(
        #     name='roles',
        #     table='middle_roles',
        # ),
        # migrations.AlterModelTable(
        #     name='userroles',
        #     table='middle_user_roles',
        # ),
    ]



# -*- coding: utf-8 -*-
"""
@File        : request_test.py
@Author      : yu wen yang
@Time        : 2022/5/10 1:23 下午
@Description :
"""
import json
import os
import django
os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'django_simple_departments.settings')
django.setup()
if __name__ == '__main__':

    from departments.views.department import create_department, DepartmentViewSet


    def response(func):
        def wrapper(*args, **kwargs):
            res = func(*args, **kwargs)
            print(json.loads(res.content))
        return wrapper

    # 创建部门
    @response
    def create_department_():
        post_data = {
            "name": "python",
            "parent_id": 2,
            "charger_id": None,
            "organization_id": 1
        }
        res = create_department(post_data)
        return res


    obj = DepartmentViewSet(1)
    # print(obj.list("sub", 2))
    print(obj.list("all"))
    # print(obj.list("all", department_name="o"))
    # print(obj.create({"name": "前端o1", "parent_id": 2, "charger_id": 11}))
    # print(obj.retrieve(3))
    # print(obj.update(2, {"name": "前端2", "parent_id": 4, "charger_id": None}))
    # print(obj.delete(2))
    # print(obj.move_show_order(9, "up"))
    # print(obj.create_department_user(5, [1, 2, 3]))
    # print(obj.department_user_list(5,))
    # print(obj.delete_department_user(5, [11]))






# Generated by Django 2.2.8 on 2022-05-10 03:32

import django.contrib.postgres.fields
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Department',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True, verbose_name='创建时间')),
                ('updated_at', models.DateTimeField(auto_now=True, verbose_name='最后更新时间')),
                ('name', models.CharField(max_length=32, verbose_name='部门名称')),
                ('path', django.contrib.postgres.fields.ArrayField(base_field=models.IntegerField(verbose_name='上级部门ID'), null=True, size=None, verbose_name='所属部门路径')),
                ('organization_id', models.IntegerField(verbose_name='组织id')),
                ('is_deleted', models.BooleanField(default=False, verbose_name='部门是否删除, 默认False')),
            ],
            options={
                'db_table': 'department',
                'unique_together': {('name', 'organization_id')},
                'index_together': {('organization_id', 'is_deleted')},
            },
        ),
        migrations.CreateModel(
            name='UserInformation',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True, verbose_name='创建时间')),
                ('updated_at', models.DateTimeField(auto_now=True, verbose_name='最后更新时间')),
                ('user_id', models.IntegerField(unique=True, verbose_name='用户id')),
                ('position', models.CharField(max_length=64, verbose_name='职位')),
                ('leader_user_id', models.IntegerField(verbose_name='直属领导id')),
                ('is_deleted', models.BooleanField(default=False, verbose_name='部门是否删除, 默认False')),
            ],
            options={
                'db_table': 'user_information',
            },
        ),
        migrations.CreateModel(
            name='DepartmentUserMap',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True, verbose_name='创建时间')),
                ('updated_at', models.DateTimeField(auto_now=True, verbose_name='最后更新时间')),
                ('user_id', models.IntegerField(verbose_name='用户id')),
                ('department', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='departments.Department', verbose_name='部门id')),
            ],
            options={
                'db_table': 'department_user_map',
                'unique_together': {('department', 'user_id')},
            },
        ),
    ]



# Generated by Django 2.2.8 on 2022-05-20 14:47

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('departments', '0006_auto_20220512_1159'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='department',
            unique_together=set(),
        ),
    ]



# Generated by Django 2.2.8 on 2022-05-12 11:38

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('departments', '0004_auto_20220512_1136'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='department',
            options={'ordering': ['show_order']},
        ),
        migrations.RemoveField(
            model_name='department',
            name='sort_num',
        ),
        migrations.AddField(
            model_name='department',
            name='show_order',
            field=models.IntegerField(default=0, verbose_name='顺序'),
        ),
    ]



# Generated by Django 2.2.8 on 2022-05-24 15:12

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('departments', '0008_role_userrole'),
    ]

    operations = [
        # migrations.RenameModel(
        #     old_name='Role',
        #     new_name='Roles',
        # ),
        # migrations.RenameModel(
        #     old_name='UserRole',
        #     new_name='UserRoles',
        # ),
    ]



# -*- coding: utf-8 -*-
"""
@File        : setup.py
@Author      : yu wen yang
@Time        : 2022/4/28 2:43 下午
@Description :
"""
import setuptools

setuptools.setup(
    name="django-simple-org",
    version="0.1.19",
    author="yuwenyang",
    author_email="ywyhpnn@126.com",
    description="组织架构",
    long_description="组织架构",
    long_description_content_type="text/markdown",
    packages=setuptools.find_packages(exclude=[
        "django_simple_departments", "django_simple_departments.*"
    ]),
    classifiers=[
        "Programming Language :: Python :: 3"
    ],
    install_requires=[],
    python_requires=">=3",
)

